@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -37,17 +37,15 @@
  * a XLIFF tag is represented by a TAGRANGE_IMAGE_SYMBOL in the 'plainttext'
  * and a struct TagRange
  *
- * describes which tag is behind TAGRANGE_IMAGE_SYMBOL char 
+ * describes which tag is behind TAGRANGE_IMAGE_SYMBOL char
  * (or chars -- starting and ending) in source or target string
  * start==end for non-paired tags
  */
-struct InlineTag
-{
+struct InlineTag {
     //sub       = can contain <sub>-flow tag
     //recursive = can contain other inline markup tags
     ///@see http://docs.oasis-open.org/xliff/v1.2/os/xliff-core.html
-    enum InlineElement
-    {
+    enum InlineElement {
         _unknown,
         bpt,    //sub
         ept,    //sub
@@ -73,10 +71,10 @@ struct InlineTag
     QString equivText;
     QString ctype;
 
-    explicit InlineTag(): start(-1), end(-1), type(_unknown){}
+    explicit InlineTag(): start(-1), end(-1), type(_unknown) {}
 
-    InlineTag(int start_, int end_, InlineElement type_,QString id_=QString(),QString xid_=QString(),QString equivText_=QString(),QString ctype_=QString())
-        : start(start_), end(end_), type(type_), id(id_), xid(xid_), equivText(equivText_), ctype(ctype_){}
+    InlineTag(int start_, int end_, InlineElement type_, QString id_ = QString(), QString xid_ = QString(), QString equivText_ = QString(), QString ctype_ = QString())
+        : start(start_), end(end_), type(type_), id(id_), xid(xid_), equivText(equivText_), ctype(ctype_) {}
 
     /**
      * for situations when target doesn't contain tag
@@ -86,7 +84,10 @@ struct InlineTag
      *
      * @see getPlaceholder()
      */
-    bool isEmpty()const{return start==-1;}
+    bool isEmpty()const
+    {
+        return start == -1;
+    }
 
     /**
      * used to denote tag that doesn't present in target,
@@ -100,16 +101,28 @@ struct InlineTag
     ///@returns 0 if type is unknown
     static InlineElement getElementType(const QByteArray&);
     static const char* getElementName(InlineElement type);
-           const char* getElementName()const{return getElementName(type);}
-           const char* name()const{return getElementName();}
-    static bool isPaired(InlineElement type){return type<InlineTag::_pairedXmlTagDelimiter;}
-           bool isPaired()const{return isPaired(type);}
+    const char* getElementName()const
+    {
+        return getElementName(type);
+    }
+    const char* name()const
+    {
+        return getElementName();
+    }
+    static bool isPaired(InlineElement type)
+    {
+        return type < InlineTag::_pairedXmlTagDelimiter;
+    }
+    bool isPaired()const
+    {
+        return isPaired(type);
+    }
 
     QString displayName() const;
 
     bool operator<(const InlineTag& other)const
     {
-        return start<other.start;
+        return start < other.start;
     }
 
 };
@@ -125,23 +138,33 @@ Q_DECLARE_METATYPE(QList<InlineTag>)
  * string has each XLIFF markup tag represented by 1 symbol
  * ranges is set to list describing which tag (type, id) at which position
  */
-struct CatalogString
-{
+struct CatalogString {
     QString string;
     QList<InlineTag> tags;
 
-    CatalogString(){}
-    CatalogString(QString str):string(str){}
+    CatalogString() {}
+    CatalogString(QString str): string(str) {}
     CatalogString(QString str, QByteArray tagsByteArray);
-    QMap<QString,int> tagIdToIndex() const; //assigns same indexes for tags with same ids
+    QMap<QString, int> tagIdToIndex() const; //assigns same indexes for tags with same ids
 
     QByteArray tagsAsByteArray()const;
 
     void remove(int position, int len);
     void insert(int position, const QString& str);
-    void replace(int position, int len, const QString& str){remove(position,len);insert(position,str);}
-    void clear(){string.clear();tags.clear();}
-    bool isEmpty() const {return string.isEmpty();}
+    void replace(int position, int len, const QString& str)
+    {
+        remove(position, len);
+        insert(position, str);
+    }
+    void clear()
+    {
+        string.clear();
+        tags.clear();
+    }
+    bool isEmpty() const
+    {
+        return string.isEmpty();
+    }
 };
 Q_DECLARE_METATYPE(CatalogString)
 
