@@ -48,8 +48,7 @@ class FlowLayout: public QLayout
 {
 public:
 
-    enum User
-    {
+    enum User {
         glossary,
         webquery,
         standard
@@ -58,27 +57,27 @@ public:
     /**
      * c'tor for glossary view
      */
-    FlowLayout(User user=standard, QWidget *signalingWidget = 0,
-               const QVector<QAction*>& actions=QVector<QAction*>(), int margin = 0, int spacing = -1);
+    explicit FlowLayout(User user = standard, QWidget *signalingWidget = nullptr,
+               const QVector<QAction*>& actions = QVector<QAction*>(), int margin = 0, int spacing = -1);
 
-    ~FlowLayout();
+    ~FlowLayout() override;
 
-    void addItem(QLayoutItem *item);
-    Qt::Orientations expandingDirections() const;
-    bool hasHeightForWidth() const;
-    int heightForWidth(int) const;
-    int count() const;
-    QLayoutItem *itemAt(int index) const;
-    QSize minimumSize() const;
-    void setGeometry(const QRect &rect);
-    QSize sizeHint() const;
-    QLayoutItem *takeAt(int index);
+    void addItem(QLayoutItem *item) override;
+    Qt::Orientations expandingDirections() const override;
+    bool hasHeightForWidth() const override;
+    int heightForWidth(int) const override;
+    int count() const override;
+    QLayoutItem *itemAt(int index) const override;
+    QSize minimumSize() const override;
+    void setGeometry(const QRect &rect) override;
+    QSize sizeHint() const override;
+    QLayoutItem *takeAt(int index) override;
 
     /**
      * @param term is the term matched
      * @param entry is index of entry in the Glossary list
      */
-    void addTerm(const QString& term, const QByteArray& entryId, bool capFirst=false);
+    void addTerm(const QString& term, const QByteArray& entryId, bool capFirst = false);
     void clearTerms();
 
 private:
