@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -42,10 +42,10 @@ class PhasesModel;
 class MyTreeView;
 class PhasesWindow: public QDialog
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    PhasesWindow(Catalog* catalog, QWidget *parent);
-    ~PhasesWindow(){}
+    explicit PhasesWindow(Catalog* catalog, QWidget *parent);
+    ~PhasesWindow() {}
 
 private slots:
     void displayPhaseNotes(const QModelIndex& current);
@@ -73,15 +73,18 @@ private:
 
 class MyTreeView: public QTreeView
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    MyTreeView(QWidget* parent):QTreeView(parent){}
-    ~MyTreeView(){}
+    explicit MyTreeView(QWidget* parent): QTreeView(parent) {}
+    ~MyTreeView() override {}
 
 signals:
     void currentIndexChanged(const QModelIndex& current);
 private:
-    void currentChanged(const QModelIndex& current, const QModelIndex&){emit currentIndexChanged(current);}
+    void currentChanged(const QModelIndex& current, const QModelIndex&) override
+    {
+        emit currentIndexChanged(current);
+    }
 };
 
 
