@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -34,6 +34,7 @@
 #include <kdirsortfilterproxymodel.h>
 #include <kcolorscheme.h>
 
+#include <QApplication>
 #include <QTreeView>
 #include <QTimer>
 #include <QMouseEvent>
@@ -49,41 +50,40 @@
 class PoItemDelegate: public QStyledItemDelegate
 {
 public:
-    PoItemDelegate(QObject *parent=0);
-    ~PoItemDelegate(){}
-    void paint (QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
-    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
+    PoItemDelegate(QObject *parent = 0);
+    ~PoItemDelegate() {}
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 private:
     KColorScheme m_colorScheme;
 };
 
 PoItemDelegate::PoItemDelegate(QObject *parent)
- : QStyledItemDelegate(parent)
- , m_colorScheme(QPalette::Normal)
+    : QStyledItemDelegate(parent)
+    , m_colorScheme(QPalette::Normal)
 {}
 
 QSize PoItemDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
 {
-    QString text=index.data().toString();
-    int lineCount=1;
-    int nPos=text.indexOf('\n');
-    if (nPos==-1)
-        nPos=text.size();
+    QString text = index.data().toString();
+    int lineCount = 1;
+    int nPos = text.indexOf('\n');
+    if (nPos == -1)
+        nPos = text.size();
     else
-        lineCount+=text.count('\n');
+        lineCount += text.count('\n');
     static QFontMetrics metrics(option.font);
-    return QSize(metrics.averageCharWidth()*nPos, metrics.height()*lineCount);
+    return QSize(metrics.averageCharWidth() * nPos, metrics.height() * lineCount);
 }
 
-void PoItemDelegate::paint (QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
+void PoItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
     if (index.column() != ProjectModel::Graph)
-        return QStyledItemDelegate::paint(painter,option,index);
+        return QStyledItemDelegate::paint(painter, option, index);
 
     QVariant graphData = index.data(Qt::DisplayRole);
-    if (Q_UNLIKELY( !graphData.isValid()))
-    {
-        painter->fillRect(option.rect,Qt::transparent);
+    if (Q_UNLIKELY(!graphData.isValid())) {
+        painter->fillRect(option.rect, Qt::transparent);
         return;
     }
 
@@ -93,24 +93,21 @@ void PoItemDelegate::paint (QPainter *painter, const QStyleOptionViewItem &optio
     int fuzzy = rect.width();
     int total = translated + untranslated + fuzzy;
 
-    if (total > 0)
-    {
+    if (total > 0) {
         QBrush brush;
         painter->setPen(Qt::white);
         QRect myRect(option.rect);
 
         myRect.setWidth(option.rect.width() * translated / total);
-        if (translated)
-        {
-            brush=m_colorScheme.foreground(KColorScheme::PositiveText);
+        if (translated) {
+            brush = m_colorScheme.foreground(KColorScheme::PositiveText);
             painter->fillRect(myRect, brush);
         }
 
         myRect.setLeft(myRect.left() + myRect.width());
         myRect.setWidth(option.rect.width() * fuzzy / total);
-        if (fuzzy)
-        {
-            brush=m_colorScheme.foreground(KColorScheme::NeutralText);
+        if (fuzzy) {
+            brush = m_colorScheme.foreground(KColorScheme::NeutralText);
             painter->fillRect(myRect, brush);
             // painter->drawText(myRect,Qt::AlignRight,QString("%1").arg(data.width()));
         }
@@ -118,16 +115,15 @@ void PoItemDelegate::paint (QPainter *painter, const QStyleOptionViewItem &optio
         myRect.setLeft(myRect.left() + myRect.width());
         myRect.setWidth(option.rect.width() - myRect.left() + option.rect.left());
         if (untranslated)
-            brush=m_colorScheme.foreground(KColorScheme::NegativeText);
+            brush = m_colorScheme.foreground(KColorScheme::NegativeText);
         //esle: paint what is left with the last brush used - blank, positive or neutral
 
         painter->fillRect(myRect, brush);
         // painter->drawText(myRect,Qt::AlignRight,QString("%1").arg(data.top()));
-    }
-    else if (total == -1)
-        painter->fillRect(option.rect,Qt::transparent);
+    } else if (total == -1)
+        painter->fillRect(option.rect, Qt::transparent);
     else if (total == 0)
-        painter->fillRect(option.rect,QBrush(Qt::gray));
+        painter->fillRect(option.rect, QBrush(Qt::gray));
 }
 
 
@@ -137,40 +133,51 @@ void PoItemDelegate::paint (QPainter *painter, const QStyleOptionViewItem &optio
 class SortFilterProxyModel : public KDirSortFilterProxyModel
 {
 public:
-    SortFilterProxyModel(QObject* parent=0)
+    SortFilterProxyModel(QObject* parent = nullptr)
         : KDirSortFilterProxyModel(parent)
     {
-        connect(Project::instance()->model(),SIGNAL(totalsChanged(int,int,int,bool)),this,SLOT(invalidate()));
+        connect(Project::instance()->model(), &ProjectModel::totalsChanged, this, &SortFilterProxyModel::invalidate);
     }
-    ~SortFilterProxyModel(){}
+    ~SortFilterProxyModel() {}
+    void toggleTranslatedFiles();
+    bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const override;
 protected:
     bool lessThan(const QModelIndex& left,
-                  const QModelIndex& right) const;
-    bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const;
+                  const QModelIndex& right) const override;
+private:
+    bool m_hideTranslatedFiles = false;
 };
 
+void SortFilterProxyModel::toggleTranslatedFiles()
+{
+    m_hideTranslatedFiles = !m_hideTranslatedFiles;
+    invalidateFilter();
+}
 
 bool SortFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex& source_parent) const
 {
-    bool result=false;
-    const QAbstractItemModel* model=sourceModel();
-    QModelIndex item=model->index(source_row,0,source_parent);
-/*
-    if (model->hasChildren(item))
-        model->fetchMore(item);
-*/
-    if (item.data(ProjectModel::TotalRole) == 0)
-        return false; // Hide rows with no translations
+    bool result = false;
+    const QAbstractItemModel* model = sourceModel();
+    QModelIndex item = model->index(source_row, 0, source_parent);
+    /*
+        if (model->hasChildren(item))
+            model->fetchMore(item);
+    */
+    if (item.data(ProjectModel::DirectoryRole) == 1 && item.data(ProjectModel::TotalRole) == 0)
+        return false; // Hide rows with no translations if they are folders
 
-    int i=model->rowCount(item);
-    while(--i>=0 && !result)
-        result=filterAcceptsRow(i,item);
+    if (item.data(ProjectModel::FuzzyUntrCountAllRole) == 0 && m_hideTranslatedFiles)
+        return false; // Hide rows with no untranslated items if the filter is enabled
+
+    int i = model->rowCount(item);
+    while (--i >= 0 && !result)
+        result = filterAcceptsRow(i, item);
 
     return result || QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
 }
 
 bool SortFilterProxyModel::lessThan(const QModelIndex& left,
-                                        const QModelIndex& right) const
+                                    const QModelIndex& right) const
 {
     static QCollator collator;
 //     qCWarning(LOKALIZE_LOG)<<right.column()<<"--"<<left.row()<<right.row()<<left.internalPointer()<<right.internalPointer()<<left.parent().isValid()<<right.parent().isValid();
@@ -188,9 +195,8 @@ bool SortFilterProxyModel::lessThan(const QModelIndex& left,
 
 
 
-    if (leftFileItem.isNull() || rightFileItem.isNull())
-    {
-        qCWarning(LOKALIZE_LOG)<<".isNull()";
+    if (leftFileItem.isNull() || rightFileItem.isNull()) {
+        qCWarning(LOKALIZE_LOG) << ".isNull()";
         return false;
     }
 
@@ -207,7 +213,7 @@ bool SortFilterProxyModel::lessThan(const QModelIndex& left,
         return isLessThan;
     } else if (!leftFileItem.isHidden() && rightFileItem.isHidden()) {
         return !isLessThan;
-   }
+    }
 
 
     // Hidden elements go before visible ones, if they both are
@@ -218,39 +224,39 @@ bool SortFilterProxyModel::lessThan(const QModelIndex& left,
         return false;
     }
 
-    switch(left.column()) {
+    switch (left.column()) {
     case ProjectModel::FileName:
         return collator.compare(leftFileItem.name(), rightFileItem.name()) < 0;
-    case ProjectModel::Graph:{
+    case ProjectModel::Graph: {
         QRect leftRect(left.data(Qt::DisplayRole).toRect());
         QRect rightRect(right.data(Qt::DisplayRole).toRect());
 
-        int leftAll=leftRect.left()+leftRect.top()+leftRect.width();
-        int rightAll=rightRect.left()+rightRect.top()+rightRect.width();
+        int leftAll = leftRect.left() + leftRect.top() + leftRect.width();
+        int rightAll = rightRect.left() + rightRect.top() + rightRect.width();
 
         if (!leftAll || !rightAll)
             return false;
 
-        float leftVal=(float)leftRect.left()/leftAll;
-        float rightVal=(float)rightRect.left()/rightAll;
+        float leftVal = (float)leftRect.left() / leftAll;
+        float rightVal = (float)rightRect.left() / rightAll;
 
-        if (leftVal<rightVal)
+        if (leftVal < rightVal)
             return true;
-        if (leftVal>rightVal)
+        if (leftVal > rightVal)
             return false;
 
-        leftVal=(float)leftRect.top()/leftAll;
-        rightVal=(float)rightRect.top()/rightAll;
+        leftVal = (float)leftRect.top() / leftAll;
+        rightVal = (float)rightRect.top() / rightAll;
 
-        if (leftVal<rightVal)
+        if (leftVal < rightVal)
             return true;
-        if (leftVal>rightVal)
+        if (leftVal > rightVal)
             return false;
 
-        leftVal=(float)leftRect.width()/leftAll;
-        rightVal=(float)rightRect.width()/rightAll;
+        leftVal = (float)leftRect.width() / leftAll;
+        rightVal = (float)rightRect.width() / rightAll;
 
-        if (leftVal<rightVal)
+        if (leftVal < rightVal)
             return true;
         return false;
     }
@@ -274,24 +280,25 @@ ProjectWidget::ProjectWidget(/*Catalog* catalog, */QWidget* parent)
     , m_proxyModel(new SortFilterProxyModel(this))
 //     , m_catalog(catalog)
 {
-    PoItemDelegate* delegate=new PoItemDelegate(this);
+    PoItemDelegate* delegate = new PoItemDelegate(this);
     setItemDelegate(delegate);
 
-    connect(this,SIGNAL(activated(QModelIndex)),this,SLOT(slotItemActivated(QModelIndex)));
+    connect(this, &ProjectWidget::activated, this, &ProjectWidget::slotItemActivated);
 
     m_proxyModel->setSourceModel(Project::instance()->model());
     //m_proxyModel->setDynamicSortFilter(true);
     setModel(m_proxyModel);
-    connect(Project::instance()->model(), SIGNAL(loadingAboutToStart()), this, SLOT(modelAboutToReload()));
-    connect(Project::instance()->model(), SIGNAL(loadingFinished()), this, SLOT(modelReloaded()), Qt::QueuedConnection);
+    connect(Project::instance()->model(), &ProjectModel::loadingAboutToStart, this, &ProjectWidget::modelAboutToReload);
+    connect(Project::instance()->model(), &ProjectModel::loadingFinished, this, &ProjectWidget::modelReloaded, Qt::QueuedConnection);
 
     setUniformRowHeights(true);
     setAllColumnsShowFocus(true);
-    int widthDefaults[]={6,1,1,1,1,1,4,4};
-    int i=sizeof(widthDefaults)/sizeof(int);
-    int baseWidth=columnWidth(0);
-    while(--i>=0)
-        setColumnWidth(i, baseWidth*widthDefaults[i]/2);
+    int widthDefaults[] = {6, 1, 1, 1, 1, 1, 1, 4, 4, 4};
+    //FileName, Graph, TotalCount, TranslatedCount, FuzzyCount, UntranslatedCount, IncompleteCount, SourceDate, TranslationDate, LastTranslator
+    int i = sizeof(widthDefaults) / sizeof(int);
+    int baseWidth = columnWidth(0);
+    while (--i >= 0)
+        setColumnWidth(i, baseWidth * widthDefaults[i] / 2);
 
     setSortingEnabled(true);
     sortByColumn(0, Qt::AscendingOrder);
@@ -303,32 +310,38 @@ ProjectWidget::ProjectWidget(/*Catalog* catalog, */QWidget* parent)
     new HeaderViewMenuHandler(header());
 
     KConfig config;
-    KConfigGroup stateGroup(&config,"ProjectWindow");
-    header()->restoreState(QByteArray::fromBase64( stateGroup.readEntry("ListHeaderState", QByteArray()) ));
+    KConfigGroup stateGroup(&config, "ProjectWindow");
+    header()->restoreState(QByteArray::fromBase64(stateGroup.readEntry("ListHeaderState", QByteArray())));
+    i = sizeof(widthDefaults) / sizeof(int);
+    while (--i >= 0) {
+        if (columnWidth(i) > 5 * baseWidth * widthDefaults[i]) {
+            //The column width is more than 5 times its normal width
+            setColumnWidth(i, 5 * baseWidth * widthDefaults[i]);
+        }
+    }
 }
 
 ProjectWidget::~ProjectWidget()
 {
     KConfig config;
-    KConfigGroup stateGroup(&config,"ProjectWindow");
-    stateGroup.writeEntry("ListHeaderState",header()->saveState().toBase64());
+    KConfigGroup stateGroup(&config, "ProjectWindow");
+    stateGroup.writeEntry("ListHeaderState", header()->saveState().toBase64());
 }
 
 void ProjectWidget::modelAboutToReload()
 {
-    m_currentItemPathBeforeReload=currentItem();
+    m_currentItemPathBeforeReload = currentItem();
 }
 
 void ProjectWidget::modelReloaded()
 {
-    int i=10;
-    while(--i>=0)
-    {
-        QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents|QEventLoop::ExcludeSocketNotifiers|QEventLoop::WaitForMoreEvents, 100);
+    int i = 10;
+    while (--i >= 0) {
+        QCoreApplication::processEvents(QEventLoop::ExcludeUserInputEvents | QEventLoop::ExcludeSocketNotifiers | QEventLoop::WaitForMoreEvents, 100);
         if (setCurrentItem(m_currentItemPathBeforeReload))
             break;
     }
-    if (proxyModel()->filterRegExp().pattern().size()>2)
+    if (proxyModel()->filterRegExp().pattern().size() > 2)
         expandItems();
 }
 
@@ -348,8 +361,8 @@ QString ProjectWidget::currentItem() const
     if (!currentIndex().isValid())
         return QString();
     return Project::instance()->model()->itemForIndex(
-            m_proxyModel->mapToSource(currentIndex())
-                                                     ).localPath();
+               m_proxyModel->mapToSource(currentIndex())
+           ).localPath();
 }
 
 bool ProjectWidget::currentIsTranslationFile() const
@@ -362,44 +375,42 @@ bool ProjectWidget::currentIsTranslationFile() const
 
 void ProjectWidget::slotItemActivated(const QModelIndex& index)
 {
-    if (currentIsTranslationFile())
-    {
+    if (currentIsTranslationFile()) {
         ProjectModel * srcModel = static_cast<ProjectModel *>(static_cast<QSortFilterProxyModel*>(m_proxyModel)->sourceModel());
         QModelIndex srcIndex = static_cast<QSortFilterProxyModel*>(m_proxyModel)->mapToSource(index);
         QUrl fileUrl = srcModel->beginEditing(srcIndex);
 
-        emit fileOpenRequested(fileUrl.toLocalFile());
+        emit fileOpenRequested(fileUrl.toLocalFile(), !(QApplication::keyboardModifiers() & Qt::ControlModifier));
     }
 }
 
-static void recursiveAdd(QStringList& list, const QModelIndex& idx)
+void ProjectWidget::recursiveAdd(QStringList& list, const QModelIndex& idx) const
 {
-    ProjectModel& model=*(Project::instance()->model());
+    if (!m_proxyModel->filterAcceptsRow(idx.row(), idx.parent())) {
+        return;
+    }
+    ProjectModel& model = *(Project::instance()->model());
     const KFileItem& item(model.itemForIndex(idx));
-    if (item.isDir())
-    {
-        int j=model.rowCount(idx);
-        while (--j>=0)
-        {
-            const KFileItem& childItem(model.itemForIndex(idx.child(j,0)));
+    if (item.isDir()) {
+        int j = model.rowCount(idx);
+        while (--j >= 0) {
+            const KFileItem& childItem(model.itemForIndex(idx.child(j, 0)));
 
             if (childItem.isDir())
-                recursiveAdd(list,idx.child(j,0));
-            else
+                recursiveAdd(list, idx.child(j, 0));
+            else if (m_proxyModel->filterAcceptsRow(j, idx))
                 list.prepend(childItem.localPath());
         }
-    }
-    else //if (!list.contains(u))
+    } else //if (!list.contains(u))
         list.prepend(item.localPath());
 }
 
 QStringList ProjectWidget::selectedItems() const
 {
     QStringList list;
-    foreach(const QModelIndex& item, selectedIndexes())
-    {
-        if (item.column()==0)
-            recursiveAdd(list,m_proxyModel->mapToSource(item));
+    foreach (const QModelIndex& item, selectedIndexes()) {
+        if (item.column() == 0)
+            recursiveAdd(list, m_proxyModel->mapToSource(item));
     }
 
     return list;
@@ -407,12 +418,12 @@ QStringList ProjectWidget::selectedItems() const
 
 void ProjectWidget::expandItems(const QModelIndex& parent)
 {
-    const QAbstractItemModel* m=model();
+    const QAbstractItemModel* m = model();
     expand(parent);
 
-    int i=m->rowCount(parent);
-    while(--i>=0)
-        expandItems(m->index(i,0,parent));
+    int i = m->rowCount(parent);
+    while (--i >= 0)
+        expandItems(m->index(i, 0, parent));
 }
 
 
@@ -435,8 +446,7 @@ QModelIndex ProjectWidget::gotoIndexPrevNext(const QModelIndex& currentIndex, in
 
     // Unless first or last sibling reached, continue with previous or next
     // sibling, otherwise continue with previous or next parent
-    while (index.isValid())
-    {
+    while (index.isValid()) {
         sibling = index.sibling(index.row() + direction, index.column());
         if (sibling.isValid())
             return sibling;
@@ -450,11 +460,9 @@ ProjectWidget::gotoIndexResult ProjectWidget::gotoIndexFind(
 {
     QModelIndex index = currentIndex;
 
-    while (index.isValid())
-    {
+    while (index.isValid()) {
         // Set current index and show it if role is found for this index
-        if (gotoIndexCheck(index, role))
-        {
+        if (gotoIndexCheck(index, role)) {
             clearSelection();
             setCurrentIndex(index);
             scrollTo(index);
@@ -463,8 +471,7 @@ ProjectWidget::gotoIndexResult ProjectWidget::gotoIndexFind(
 
         // Handle child recursively if index is not a leaf
         QModelIndex child = index.child((direction == 1) ? 0 : (m_proxyModel->rowCount(index) - 1), index.column());
-        if (child.isValid())
-        {
+        if (child.isValid()) {
             ProjectWidget::gotoIndexResult result = gotoIndexFind(child, role, direction);
             if (result != gotoIndex_notfound)
                 return result;
@@ -491,16 +498,53 @@ ProjectWidget::gotoIndexResult ProjectWidget::gotoIndex(
     return gotoIndexFind(index, role, direction);
 }
 
-void ProjectWidget::gotoPrevFuzzyUntr()    {gotoIndex(currentIndex(), ProjectModel::FuzzyUntrCountRole, -1);}
-void ProjectWidget::gotoNextFuzzyUntr()    {gotoIndex(currentIndex(), ProjectModel::FuzzyUntrCountRole, +1);}
-void ProjectWidget::gotoPrevFuzzy()        {gotoIndex(currentIndex(), ProjectModel::FuzzyCountRole,     -1);}
-void ProjectWidget::gotoNextFuzzy()        {gotoIndex(currentIndex(), ProjectModel::FuzzyCountRole,     +1);}
-void ProjectWidget::gotoPrevUntranslated() {gotoIndex(currentIndex(), ProjectModel::UntransCountRole,   -1);}
-void ProjectWidget::gotoNextUntranslated() {gotoIndex(currentIndex(), ProjectModel::UntransCountRole,   +1);}
-void ProjectWidget::gotoPrevTemplateOnly() {gotoIndex(currentIndex(), ProjectModel::TemplateOnlyRole,   -1);}
-void ProjectWidget::gotoNextTemplateOnly() {gotoIndex(currentIndex(), ProjectModel::TemplateOnlyRole,   +1);}
-void ProjectWidget::gotoPrevTransOnly()    {gotoIndex(currentIndex(), ProjectModel::TransOnlyRole,      -1);}
-void ProjectWidget::gotoNextTransOnly()    {gotoIndex(currentIndex(), ProjectModel::TransOnlyRole,      +1);}
+void ProjectWidget::gotoPrevFuzzyUntr()
+{
+    gotoIndex(currentIndex(), ProjectModel::FuzzyUntrCountRole, -1);
+}
+void ProjectWidget::gotoNextFuzzyUntr()
+{
+    gotoIndex(currentIndex(), ProjectModel::FuzzyUntrCountRole, +1);
+}
+void ProjectWidget::gotoPrevFuzzy()
+{
+    gotoIndex(currentIndex(), ProjectModel::FuzzyCountRole,     -1);
+}
+void ProjectWidget::gotoNextFuzzy()
+{
+    gotoIndex(currentIndex(), ProjectModel::FuzzyCountRole,     +1);
+}
+void ProjectWidget::gotoPrevUntranslated()
+{
+    gotoIndex(currentIndex(), ProjectModel::UntransCountRole,   -1);
+}
+void ProjectWidget::gotoNextUntranslated()
+{
+    gotoIndex(currentIndex(), ProjectModel::UntransCountRole,   +1);
+}
+void ProjectWidget::gotoPrevTemplateOnly()
+{
+    gotoIndex(currentIndex(), ProjectModel::TemplateOnlyRole,   -1);
+}
+void ProjectWidget::gotoNextTemplateOnly()
+{
+    gotoIndex(currentIndex(), ProjectModel::TemplateOnlyRole,   +1);
+}
+void ProjectWidget::gotoPrevTransOnly()
+{
+    gotoIndex(currentIndex(), ProjectModel::TransOnlyRole,      -1);
+}
+void ProjectWidget::gotoNextTransOnly()
+{
+    gotoIndex(currentIndex(), ProjectModel::TransOnlyRole,      +1);
+}
+void ProjectWidget::toggleTranslatedFiles()
+{
+    m_proxyModel->toggleTranslatedFiles();
+}
 
-QSortFilterProxyModel* ProjectWidget::proxyModel(){return m_proxyModel;}
+QSortFilterProxyModel* ProjectWidget::proxyModel()
+{
+    return m_proxyModel;
+}
 
