@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -40,7 +40,7 @@ class ProjectWidget: public QTreeView
 {
     Q_OBJECT
 public:
-    ProjectWidget(QWidget* parent);
+    explicit ProjectWidget(QWidget* parent);
     ~ProjectWidget();
 
     bool setCurrentItem(const QString&);
@@ -49,7 +49,7 @@ public:
     bool currentIsTranslationFile() const;
 
     QSortFilterProxyModel* proxyModel();
-    void expandItems(const QModelIndex& parent=QModelIndex());
+    void expandItems(const QModelIndex& parent = QModelIndex());
 
     void gotoPrevFuzzyUntr();
     void gotoNextFuzzyUntr();
@@ -61,9 +61,10 @@ public:
     void gotoNextTemplateOnly();
     void gotoPrevTransOnly();
     void gotoNextTransOnly();
+    void toggleTranslatedFiles();
 
 signals:
-    void fileOpenRequested(const QString&);
+    void fileOpenRequested(const QString&, const bool setAsActive);
     void newWindowOpenRequested(const QUrl&);
 
 private slots:
@@ -78,6 +79,7 @@ private:
     QModelIndex gotoIndexPrevNext(const QModelIndex& currentIndex, int direction) const;
     gotoIndexResult gotoIndexFind(const QModelIndex& currentIndex, ProjectModel::AdditionalRoles role, int direction);
     gotoIndexResult gotoIndex(const QModelIndex& currentIndex, ProjectModel::AdditionalRoles role, int direction);
+    void recursiveAdd(QStringList& list, const QModelIndex& idx) const;
 
     SortFilterProxyModel* m_proxyModel;
     QString m_currentItemPathBeforeReload;
