@@ -34,31 +34,31 @@
 
 
 QaView::QaView(QWidget* parent)
- : QDockWidget ( i18nc("@title:window","Quality Assurance"), parent)
- , m_browser(new QTreeView(this))
+    : QDockWidget(i18nc("@title:window", "Quality Assurance"), parent)
+    , m_browser(new QTreeView(this))
 {
     setObjectName(QStringLiteral("QaView"));
 
     if (!QaModel::isInstantiated())
         QaModel::instance()->loadRules(Project::instance()->qaPath());
-    m_qaModel=QaModel::instance();
+    m_qaModel = QaModel::instance();
 
     setWidget(m_browser);
     m_browser->setModel(m_qaModel);
     m_browser->setRootIsDecorated(false);
     m_browser->setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    QAction* action=new QAction(i18nc("@action:inmenu", "Add"), m_browser);
-    connect(action, SIGNAL(triggered()), this, SLOT(addRule()));
+    QAction* action = new QAction(i18nc("@action:inmenu", "Add"), m_browser);
+    connect(action, &QAction::triggered, this, &QaView::addRule);
     m_browser->addAction(action);
 
-    action=new QAction(i18nc("@action:inmenu", "Remove"), m_browser);
-    connect(action, SIGNAL(triggered()), this, SLOT(removeRule()));
+    action = new QAction(i18nc("@action:inmenu", "Remove"), m_browser);
+    connect(action, &QAction::triggered, this, &QaView::removeRule);
     m_browser->addAction(action);
-    
+
     m_browser->setAlternatingRowColors(true);
-    
-    connect(m_qaModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)), this, SIGNAL(rulesChanged()));
+
+    connect(m_qaModel, &QaModel::dataChanged, this, &QaView::rulesChanged);
 }
 
 QaView::~QaView()
@@ -68,17 +68,17 @@ QaView::~QaView()
 bool QaView::loadRules(QString filename)
 {
     if (filename.isEmpty())
-        filename=Project::instance()->qaPath();
+        filename = Project::instance()->qaPath();
 
-    bool ok=m_qaModel->loadRules(filename);
+    bool ok = m_qaModel->loadRules(filename);
     if (ok)
-        m_filename=filename;
+        m_filename = filename;
     return ok;
 }
 
 bool QaView::saveRules(QString filename)
 {
-    return m_qaModel->saveRules(filename.isEmpty()?m_filename:filename);
+    return m_qaModel->saveRules(filename.isEmpty() ? m_filename : filename);
 }
 
 QVector< Rule > QaView::rules() const
@@ -89,34 +89,30 @@ QVector< Rule > QaView::rules() const
 
 void QaView::addRule()
 {
-    QModelIndex newRule=m_qaModel->appendRow();
+    QModelIndex newRule = m_qaModel->appendRow();
     m_browser->selectionModel()->select(newRule, QItemSelectionModel::ClearAndSelect);
     m_browser->edit(newRule);
 }
 
 void QaView::removeRule()
 {
-    foreach(const QModelIndex& rowIndex, m_browser->selectionModel()->selectedRows())
+    foreach (const QModelIndex& rowIndex, m_browser->selectionModel()->selectedRows())
         m_qaModel->removeRow(rowIndex);
 }
 
 int findMatchingRule(const QVector<Rule>& rules, const QString& source, const QString& target,
-                    QVector<StartLen>& positions)
+                     QVector<StartLen>& positions)
 {
-    for(QVector<Rule>::const_iterator it=rules.constBegin();it!=rules.constEnd();it++)
-    {
-        if (it->sources.first().indexIn(source)!=-1)
-        {
-            if (it->falseFriends.first().indexIn(target)!=-1)
-            {
-                if (positions.size())
-                {
-                    positions[0].start=it->sources.first().pos();
-                    positions[0].len=it->sources.first().matchedLength();
-                    positions[1].start=it->falseFriends.first().pos();
-                    positions[1].len=it->falseFriends.first().matchedLength();
+    for (QVector<Rule>::const_iterator it = rules.constBegin(); it != rules.constEnd(); it++) {
+        if (it->sources.first().indexIn(source) != -1) {
+            if (it->falseFriends.first().indexIn(target) != -1) {
+                if (positions.size()) {
+                    positions[0].start = it->sources.first().pos();
+                    positions[0].len = it->sources.first().matchedLength();
+                    positions[1].start = it->falseFriends.first().pos();
+                    positions[1].len = it->falseFriends.first().matchedLength();
                 }
-                return it-rules.constBegin();
+                return it - rules.constBegin();
             }
         }
     }
